function [ ] = fourier(  )
% Function for discrete fourier transform
%
%This function is part of TSProg Matlab toolbox
%by Marcin Zajac

listbox = get( findobj( 'Tag', 'MAIN.listbox1' ) );
StName = listbox.String( listbox.Value, : );
LogHead1 = [ 'Discrete Fast Fourier Transform performed on ' StName ' station. North Component' ];
LogHead2 = 'Power   Frequency   Period  Amplitude';
LogHead3 = '                          1000*main unit';



plot1 = findobj( 'Tag', 'plotN' );		%Getting stored data
plot2 = findobj( 'Tag', 'plotE' );
plot3 = findobj( 'Tag', 'plotH' );


data1 = get( plot1, 'UserData' );		%continue getting data
data2 = get( plot2, 'UserData' );
data3 = get( plot3, 'UserData' );

%----------------------------- North component ------------------------------
Y = fft( data1.Layer1(  :, 2 ) );		%computing fast fourier transform
Y1 = Y ( 1 );
Y( 1 ) = [ ];

n = length( Y );
power = abs( Y( 1 : n / 2 ) ).^2;		%computing power
freq = ( 1 : n / 2 ) /  ( n / 2 ) * ( 1 / 2 );	%computing freqiencies


power = fliplr( power *.1 );
period = 1./ freq;

nonzeros = find( data1.Layer1( :, 2 ) );
modulus = size( nonzeros );
modulus = modulus( 1 );

sizeOf = size( power );
sizeOf = sizeOf( 1 );
t = n/2;					%number of fourier series
if t > sizeOf 
    t = sizeOf - 1;
end

W(1:t,1)=Y(1:t);
W(1:t,2)=real(Y(1:t));
W(1:t,3)=imag(Y(1:t));
W(1:t,4)=transpose(period(1:t));    		%period
period = transpose( period( 1: t ) );
W(1:t,5)=transpose(power(1:t));     		%power
power = power(1:t);
W(1:t,6)=(sqrt(W(1:t,2).^2+W(1:t,3).^2))/t;
W(1:t,7)=2*abs(Y(1:t));                           %amplitude 
amplitude = abs( Y( 1 : t ) ) * 2 / max( period ); %amplitude
W(1:t,8)=W(1:t,6).*1000;
W(1:t,9)=atan(W(1:t,3)./W(1:t,2));
W(1:t,10)=(W(1:t,9).*180)./pi;
YY=real(Y(1:t))+imag(Y(1:t)).*sqrt(-1);
W(1:t,11)=angle(Y(1:t))+pi/2;
phase=(W(1:t,11).*180)./pi;     %phase
freq=transpose(freq(1:t));     %freq

dataS1 = SortByColumn( [ power freq ] );		%prepare to store calculated data
dataS2 = SortByColumn( [ power period ] );
dataS3 = SortByColumn( [ power amplitude phase ] );

data1.Layer4 = dataS1;					%store data for further use
data1.Layer5 = dataS2;
data1.Layer6 = dataS3( :, :, : );



set( plot1, 'UserData', data1 );
%---------------------------------------------------------------------------

%----------------------------- East component ------------------------------
Y = fft( data2.Layer1(  :, 2 ) );
Y1 = Y ( 1 );
Y( 1 ) = [ ];

n = length( Y );
power = abs( Y( 1 : n / 2 ) ).^2;
freq = ( 1 : n / 2 ) /  ( n / 2 ) * ( 1 / 2 );


power = fliplr( power *.1 );
period = 1./ freq;

nonzeros = find( data2.Layer1( :, 2 ) );
modulus = size( nonzeros );
modulus = modulus( 1 );

t=244;
sizeOf = size( power );
sizeOf = sizeOf( 1 );
if t > sizeOf 
    t = sizeOf - 1;
end
W(1:t,1)=Y(1:t);
W(1:t,2)=real(Y(1:t));
W(1:t,3)=imag(Y(1:t));
W(1:t,4)=transpose(period(1:t));    %period
period = transpose( period( 1: t ) );
W(1:t,5)=transpose(power(1:t));     %power
power = power(1:t);
W(1:t,6)=(sqrt(W(1:t,2).^2+W(1:t,3).^2))/t;
W(1:t,7)=abs(Y(1:t));              
amplitude = abs( Y( 1 : t ) ) * 2 / max( period );  %2*abs(Y(1:t/2))
W(1:t,8)=W(1:t,6).*1000;
W(1:t,9)=atan(W(1:t,3)./W(1:t,2));
W(1:t,10)=(W(1:t,9).*180)./pi;
YY=real(Y(1:t))+imag(Y(1:t)).*sqrt(-1);
W(1:t,11)=unwrap(angle(Y(1:t)))+pi/2;
phase=(W(1:t,11).*180)./pi;     %phase
freq=transpose(freq(1:t));     %freq

dataS1 = SortByColumn( [ power freq ] );
dataS2 = SortByColumn( [ power period ] );
dataS3 = SortByColumn( [ power amplitude phase ] );

data2.Layer4 = dataS1;
data2.Layer5 = dataS2;
data2.Layer6 = dataS3( :, :, : );

set( plot2, 'UserData', data2 );
%---------------------------------------------------------------------------

%----------------------------- Height component ------------------------------
Y = fft( data3.Layer1(  :, 2 ) );
Y1 = Y ( 1 );
Y( 1 ) = [ ];

n = length( Y );
power = abs( Y( 1 : n / 2 ) ).^2;
freq = ( 1 : n / 2 ) /  ( n / 2 ) * ( 1 / 2 );


power = fliplr( power *.1 );
period = 1./ freq;

nonzeros = find( data3.Layer1( :, 2 ) );
modulus = size( nonzeros );
modulus = modulus( 1 );

sizeOf = size( power );
sizeOf = sizeOf( 1 );
t=244;
if t > sizeOf 
    t = sizeOf - 1;
end
W(1:t,1)=Y(1:t);
W(1:t,2)=real(Y(1:t));
W(1:t,3)=imag(Y(1:t));
W(1:t,4)=transpose(period(1:t));    %period
period = transpose( period( 1: t ) );
W(1:t,5)=transpose(power(1:t));     %power
power = power(1:t);
W(1:t,6)=(sqrt(W(1:t,2).^2+W(1:t,3).^2))/t;
W(1:t,7)=abs(Y(1:t));                          %amplitude
amplitude = abs( Y( 1 : t ) ) * 2 / max( period );  
W(1:t,8)=W(1:t,6).*1000;
W(1:t,9)=atan(W(1:t,3)./W(1:t,2));
W(1:t,10)=(W(1:t,9).*180)./pi;
YY=real(Y(1:t))+imag(Y(1:t)).*sqrt(-1);
W(1:t,11)=unwrap(angle(Y(1:t)))+pi/2;
phase=(W(1:t,11).*180)./pi;     %phase
freq=transpose(freq(1:t));     %freq


dataS1 = SortByColumn( [ power freq ] );
dataS2 = SortByColumn( [ power period ] );
dataS3 = SortByColumn( [ power amplitude phase ] );

data3.Layer4 = dataS1;
data3.Layer5 = dataS2;
data3.Layer6 = dataS3( :, :, : );

set( plot3, 'UserData', data3 );


%--------------------------------------------------------------------------

fillOutputFFT;