function SP3_interp(inputfile,outputfile,delt)

% Interpolate SP3 data from 15 minute to 30 second
% 
% %%%%%%%%%% HELP %%%%%%%%%%
% 
% SP3_interp('inputfile','outputfile',delt)
% 
% Input Data
% inputfile = input filename (SP3X SP3Y SP3Z SP3clk SP3time)
% delt = observation rate, second
% nXYZ = number of points used in LG orbit interpolation
% nCLK = number of points used in LG precise clock interpolation
% 
% Output Data
% outputfile = output filename (SP3X SP3Y SP3Z SP3clk SP3time nXYZ nCLK)
% 
% Written by  Phakphong Homniam
% April 15, 2003

%%%%%%%%%% BEGIN %%%%%%%%%

fprintf('\n:-----Start SP3_interp.m-----:\n');

% Set a value for the current time to compute an elasped time for the function
t0 = clock;

NAJ = 999999.999999;
nXYZ = 9;
nCLK = 5;

command_str = sprintf('load %s',deblank(inputfile));
eval(command_str);

SP3time;    SP3X;   SP3Y;   SP3Z;   SP3clk;     

prn = SP3X(1,:);
numsat = length(prn);
newSP3X(1,1:numsat) = SP3X(1,:);
newSP3Y(1,1:numsat) = SP3Y(1,:);
newSP3Z(1,1:numsat) = SP3Z(1,:);
newSP3clk(1,1:numsat) = SP3clk(1,:);
if SP3time(1,2) > SP3time(end,2)
    SP3time(end,1) = SP3time(1,1);
    SP3time(end,2) = SP3time(end,2)+604800;
end
for j = 1:numsat
    fprintf('Start process satellite no. %3u\n',prn(j));
    
    [sp3time,sp3x,sp3y,sp3z,sp3clk] ... 
        = LG_interp(nXYZ,nCLK,SP3time(:,2),SP3X(2:end,j),SP3Y(2:end,j),SP3Z(2:end,j),SP3clk(2:end,j),delt);
    numep = length(sp3time);
    newSP3X(2:numep+1,j) = sp3x;
    newSP3Y(2:numep+1,j) = sp3y;
    newSP3Z(2:numep+1,j) = sp3z;
    newSP3clk(2:numep+1,j) = sp3clk;
end

numep = length(sp3time);
GPSweek = SP3time(1,1);

%%%%%%%% RESULT %%%%%%%%

SP3time(1:numep,1) = GPSweek;
SP3time(1:numep,2) = sp3time;
SP3X = newSP3X;
SP3Y = newSP3Y;
SP3Z = newSP3Z;
SP3clk = newSP3clk;

save_file = sprintf('save %s SP3time SP3X SP3Y SP3Z SP3clk',deblank(outputfile));
eval(save_file);
fprintf('\nTime used %g minutes.\n',etime(clock,t0)/60);
fprintf('\nSuccessful YEAH!!!\n');

fprintf('\n:-----End SP3_interp.m-----:\n\n\n');

%%%%%%%%%% END %%%%%%%%%%