function SP3_processor(sp3file,savefile,prn,sep,lep,delt,type)

% Read precise satellite orbit from SP3 file 
%
% %%%%%%%%%% HELP %%%%%%%%%%
% 
% SP3_processor('sp3file','savefile',prn,sep,lep,delt,type)
% 
% Input Data
% sp3file = SP3 filename ****.sp3, string type
% savefile = output filename (data will be saved),string type
% prn = satellite number (numsatx1)
% sep = start time (UTC-[6x1])
% lep = end time (UTC-[6x1])
% delt = time interval of each epoch,second
% type = 1 linear interpolation for precise clock correction (for JPL high-rate precise orbit)
%        2 no linear interpolation(for IGS precise orbit)
% 
% Output Data
% save into output filename (***.mat file)
% SP3time = GPS time of SP3 file [GPSweek GPSsec], [numep x 2]
% SP3X, SP3Y, SP3Z = Satellite coordinate (WGS84), metres [numep+1 x numsat]
% SP3clk = Precise clock correction, microseconds [numep+1 x numsat]
%
% Written by Phakphong Homniam
% Febuary 24, 2003

%%%%%%%%%% BEGIN %%%%%%%%%%

% sp3file = input('Please input SP3 filename ****.sp3 :','s');
% prn = input('Please input satellite number :');
% sep = input('Please input start time (UTC-[6x1]) :');
% lep = input('Please input last time (UTC-[6x1]) :');
% delt = input('Please input time interval of each epoch, second :');
% % Data will be saved into the output filename
% savefile = input('Please input an output filename ****.mat :','s');

fprintf('\n:-----Start SP3_processor-----:\n');

% Set a value for the current time to compute an elasped time for the function
t0 = clock;

sep_time = utc2gps(sep,0);
lep_time = utc2gps(lep,0);
sep_sec = sep_time(2);
lep_sec = lep_time(2);
[SP3time,SP3X,SP3Y,SP3Z,Clk,remark] = FormSP3(sp3file,prn,sep_sec,lep_sec);
switch type
case 1
    SP3clk = intpSP3clk(Clk);
case 2
    SP3clk = Clk;
end
gps_sec = SP3time(:,2);
obsint = gps_sec(5)-gps_sec(4);

% If data not available in SP3
NAJ = 999999.999999;
% replace NaN with NAJ
SP3X = repNaN(SP3X,NAJ);
SP3Y = repNaN(SP3Y,NAJ);
SP3Z = repNaN(SP3Z,NAJ);
SP3clk = repNaN(SP3clk,NAJ);
% replace zero with NAJ
zero_epoch = find(SP3X == 0);
SP3X(zero_epoch) = NAJ;
zero_epoch = find(SP3Y == 0);
SP3Y(zero_epoch) = NAJ;
zero_epoch = find(SP3Z== 0);
SP3Z(zero_epoch) = NAJ;
zero_epoch = find(SP3clk == 0);
SP3clk(zero_epoch) = NAJ;

%%%%%%%% RESULT %%%%%%%%

if delt <= obsint
    delt = obsint;
    save_file = sprintf('save %s SP3time SP3X SP3Y SP3Z SP3clk Clk',deblank(savefile));
    eval(save_file);
    fprintf('\nTime used %g minutes.\n',etime(clock,t0)/60);
    fprintf('\nSuccessful YEAH!!!\n');
    fprintf('\n:-----End SP3_processor-----:\n\n\n');
    return
else
    every = delt/obsint;
    gps_epoch = [1:every:size(SP3time,1)];
    SP3time = SP3time(gps_epoch,:);
    gps_epoch = [2:every:size(SP3X,1)];
    SP3X = [SP3X(1,:);SP3X(gps_epoch,:)];
    SP3Y = [SP3X(1,:);SP3Y(gps_epoch,:)];
    SP3Z = [SP3X(1,:);SP3Z(gps_epoch,:)];
    SP3clk = [SP3X(1,:);SP3clk(gps_epoch,:)];
    save_file = sprintf('save %s SP3time SP3X SP3Y SP3Z SP3clk Clk',deblank(savefile));
    eval(save_file);
    fprintf('\nTime used %g minutes.\n',etime(clock,t0)/60);
    fprintf('\nSuccessful YEAH!!!\n');
    fprintf('\n:-----End SP3_processor-----:\n\n\n');
    return
end

%%%%%%%%%% END %%%%%%%%%%